# Revision History
## 1.2.0
- Added `percentiles` and `intervals` modules
- Added Jupyter notebooks under `example/`
- Added `pyproject.toml`, replacing `setup`
- Required python version is ">=3.10"
- Added automatic unit testing for python 3.12 

## 1.1.0
- Added `binom_fin` module for finite population sizes

## 1.0.0
- First release with `binomial` module
